==> tine20-voip_2019.11.25.tar.bz2: Phone/js/Phone-lang-sk-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Slovak (http://www.transifex.com/tine20/tine20/language/sk/)\nLanguage: sk\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Incoming call"
: ""

, "Outgoing call"
: ""

, "unknown number"
: ""

, "Phone"
: ""

, "Line"
: ""

, "Number"
: ""

, "Cancel"
: ""

, "Dial"
: ""

, "Error"
: ""

, "Not possible to dial."
: ""

, "Call contact"
: ""

, "Work"
: ""

, "Home"
: ""

, "Cell"
: ""

, "Cell private"
: ""

, "Edit phone settings"
: ""

, "Dial number"
: ""

, "Initiate a new outgoing call"
: ""

, "Phones"
: ""

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Calls this week"
: ""

, "Calls last week"
: ""

, "Calls this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Incoming and outgoing calls of last month"
: ""

, "Local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "Identifies if a calling number is a local call without leading area code."
: ""

, "own telephone number"
: ""

, "Own telephone number to prefix to internal calls."
: ""

, "Call"
: ""

, "Calls"
: ""

, "Caller Id"
: ""

, "Start"
: ""

, "Connected"
: ""

, "Disconnected"
: ""

, "Duration"
: ""

, "Ringing"
: ""

, "Direction"
: ""

, "Source"
: ""

, "Destination"
: ""

, "resolved destination"
: ""

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-sk-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Slovak (http://www.transifex.com/tine20/tine20/language/sk/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: sk\nPlural-Forms: nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: ""

, "Calls"
: ""

, "Line"
: ""

, "Caller Id"
: ""

, "Start"
: ""

, "Connected"
: ""

, "Disconnected"
: ""

, "Duration"
: ""

, "Ringing"
: ""

, "Direction"
: ""

, "Source"
: ""

, "Destination"
: ""

, "Phone"
: ""

, "Phones"
: ""

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

, "Number"
: ""

, "Cancel"
: ""

, "Dial"
: ""

, "Error"
: ""

, "Not possible to dial."
: ""

, "Edit phone settings"
: ""

, "Dial number"
: ""

, "Initiate a new outgoing call"
: ""

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Call contact"
: ""

, "Work"
: ""

, "Home"
: ""

, "Cell"
: ""

, "Cell private"
: ""

, "Incoming call"
: ""

, "Outgoing call"
: ""

, "unknown number"
: ""

, "local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: ""

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Calls last week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Calls this month"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of last month"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
